------------------------------------------------------------------------------
-- Broker_AlertFrames
-- Author: Yargoro@Arathor-EU
------------------------------------------------------------------------------
local _,ADDON = nil,select(2,...)				--Includes all functions and variables
local MODNAME = "Broker_AlertFrames"

ADDON.name = MODNAME 
ADDON.debug = string.find(GetAddOnMetadata(MODNAME,"X-Debug"),"true") and true or false
ADDON.version = "|cFF33FF99Version:"..GetAddOnMetadata(MODNAME, "Version").."|r"..(ADDON.debug and " (Debug)" or "")

function ADDON:Debug(msg)
	if self.debug and DEFAULT_CHAT_FRAME then
		DEFAULT_CHAT_FRAME:AddMessage(ADDON.name .. " (dbg): " .. tostring(msg), 1.0, 0.37, 0.37)
	end
end 

--Table helper functions 

-- Print contents of `tbl`, with indentation. indent` sets the initial level of indentation.
function ADDON:tprint(tbl, indent)
  if not indent then indent = 0 end
  for k, v in pairs(tbl) do
  	if k and v then
	  if type(k) ~= 'table' then
		local formatting = string.rep("  ", indent) .. k .. ": "
		if type(v) == "table" then
		ADDON:Debug(formatting)
		ADDON:tprint(v, indent+1)
		elseif type(v) == 'boolean' or type(v) == 'function' or type(v) == 'userdata' then
			ADDON:Debug(formatting .. tostring(v))      
		else
		ADDON:Debug(formatting .. v)
		end
	   end
	end
  end
end

function ADDON:split(s, delimiter)
    local result = {};
    for match in (s..delimiter):gmatch("(.-)"..delimiter) do
        table.insert(result, match);
    end
    return result;
end

-- Remove key k (and its value) from table t. Return a new (modified) table.
function table.removeKey(t, k)
	local i = 0
	local keys, values = {},{}
	for k,v in pairs(t) do
		i = i + 1
		keys[i] = k
		values[i] = v
	end
 
	while i>0 do
		if keys[i] == k then
			table.remove(keys, i)
			table.remove(values, i)
			break
		end
		i = i - 1
	end
 
	local a = {}
	for i = 1,#keys do
		a[keys[i]] = values[i]
	end
 
	return a
end

function table.getkey( t, value )
  for k,v in pairs(t) do
    if v==value then return k end
  end
  return nil
end

--<< Table alphabetical sort function >>----------------------------------------
function ADDON:pairsByKeys(t, f)
	local a = {}
	for n in pairs(t) do table.insert(a, n) end
		table.sort(a, f)
		local i = 0                                    --iterator variable
		local iter = function ()                       --iterator function
		i = i + 1
		if a[i] == nil then
			return nil
		else
			return a[i], t[a[i]]
		end
	end
	return iter
end

--<< Count of table elements >>-------------------------------------------------
function ADDON:tcount(tab)
	local n = #tab
	if (n == 0) then
		for _ in pairs(tab) do
			n = n + 1
		end
	end
	return n
end

